==> AsposeCellsCloud-CellsApi-24.9.tar.gz: AsposeCellsCloud-CellsApi-24.9/docs/ImageOrPrintOptions.md <==
# AsposeCellsCloud::Object::ImageOrPrintOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::ImageOrPrintOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**TextCrossType** | **string** | TextCrossType |
**GridlineType** | **string** | GridlineType |
**OutputBlankPageWhenNothingToPrint** | **boolean** |  |
**CheckWorkbookDefaultFont** | **boolean** |  |
**DefaultFont** | **string** |  |
**IsOptimized** | **boolean** |  |
**PageCount** | **int** |  |
**PageIndex** | **int** |  |
**IsFontSubstitutionCharGranularity** | **boolean** |  |
**Transparent** | **boolean** |  |
**OnlyArea** | **boolean** |  |
**SVGFitToViewPort** | **boolean** |  |
**EmbededImageNameInSvg** | **string** |  |
**AllColumnsInOnePagePerSheet** | **boolean** |  |
**PrintWithStatusDialog** | **boolean** |  |
**HorizontalResolution** | **int** |  |
**VerticalResolution** | **int** |  |
**DefaultEditLanguage** | **string** | DefaultEditLanguage |
**TiffColorDepth** | **string** | ColorDepth |
**TiffCompression** | **string** | TiffCompression |
**PrintingPage** | **string** | PrintingPageType |
**Quality** | **int** |  |
**ImageType** | **string** | ImageType |
**OnePagePerSheet** | **boolean** |  |
**TiffBinarizationMethod** | **string** | ImageBinarizationMethod |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-25.3.tar.gz: AsposeCellsCloud-CellsApi-25.3/docs/ImageOrPrintOptions.md <==
# AsposeCellsCloud::Object::ImageOrPrintOptions 

## Load the model package
```perl
use AsposeCellsCloud::Object::ImageOrPrintOptions;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**TextCrossType** | **string** | TextCrossType |
**GridlineType** | **string** | GridlineType |
**OutputBlankPageWhenNothingToPrint** | **boolean** | Indicates whether to output a blank page when there is nothing to print. |
**CheckWorkbookDefaultFont** | **boolean** |  |
**DefaultFont** | **string** |  |
**IsOptimized** | **boolean** |  |
**PageCount** | **int** |  |
**PageIndex** | **int** |  |
**IsFontSubstitutionCharGranularity** | **boolean** |  |
**Transparent** | **boolean** |  |
**OnlyArea** | **boolean** |  |
**SVGFitToViewPort** | **boolean** |  |
**EmbededImageNameInSvg** | **string** |  |
**AllColumnsInOnePagePerSheet** | **boolean** |  |
**PrintWithStatusDialog** | **boolean** |  |
**HorizontalResolution** | **int** |  |
**VerticalResolution** | **int** |  |
**DefaultEditLanguage** | **string** | DefaultEditLanguage |
**TiffColorDepth** | **string** | ColorDepth |
**TiffCompression** | **string** | TiffCompression |
**PrintingPage** | **string** | PrintingPageType |
**Quality** | **int** |  |
**ImageType** | **string** | ImageType |
**OnePagePerSheet** | **boolean** |  |
**TiffBinarizationMethod** | **string** | ImageBinarizationMethod |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
